KS PME represents a market adjusted equivalent of the Total Value to
Paid-In-Capital (TVPI). KS PME is calculated by finding the future value of
each contribution and distribution using the stock market index returns.

Formula: FV(Distributions) + NAV / FV(Contributions)

See also:
- `ks_pme_flows` and `tvpi` functions
- <https://en.wikipedia.org/wiki/Public_Market_Equivalent#Kaplan_Schoar_PME>
- <https://blog.edda.co/advanced-fund-performance-methods-pme-direct-alpha/>
